epistoch package
================

.. automodule:: epistoch
   :members:
   :undoc-members:
   :show-inheritance:

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   epistoch.utils

Submodules
----------

epistoch.experiments module
---------------------------

.. automodule:: epistoch.experiments
   :members:
   :undoc-members:
   :show-inheritance:

epistoch.seird\_ph module
-------------------------

.. automodule:: epistoch.seird_ph
   :members:
   :undoc-members:
   :show-inheritance:

epistoch.sir\_g module
----------------------

.. automodule:: epistoch.sir_g
   :members:
   :undoc-members:
   :show-inheritance:

epistoch.sir\_phg module
------------------------

.. automodule:: epistoch.sir_phg
   :members:
   :undoc-members:
   :show-inheritance:
